package pro.litvinovg.libreoffice.metadata;

import java.util.ArrayList;
import java.util.Iterator;

import org.json.JSONException;
import org.json.JSONObject;

import com.sun.star.beans.PropertyVetoException;
import com.sun.star.beans.UnknownPropertyException;
import com.sun.star.beans.XPropertySet;
import com.sun.star.lang.IllegalArgumentException;
import com.sun.star.lang.WrappedTargetException;
import com.sun.star.text.XText;
import com.sun.star.text.XTextCursor;
import com.sun.star.text.XTextField;
import com.sun.star.text.XTextRange;
import com.sun.star.uno.UnoRuntime;
import static pro.litvinovg.libreoffice.metadata.Document.*;
public class OutlineElement {

	private String elementName;
	private ArrayList<MetadataElement> metadata = null;

	public String getName() {
		return elementName;
	}

	private XTextRange textRange;

	public OutlineElement(XTextRange textRange, String name) {
		this.textRange = textRange;
		this.elementName = name;
		this.metadata = new ArrayList<MetadataElement>();
	}
	
	public Object[][] metadataToArray() {
		Object [] [] result = null; 
		int size = metadata.size();
		if (metadata.size() == 0) {
			result = new Object[][] {
				{null, null},
				{null, null},
				{null, null},
			};
		} else {
			result = new Object [size] [2];
			for (int i = 0; i < size; i++) {
				result[i][0] = metadata.get(i).getName();
				result[i][1] = metadata.get(i).getValue();
			}
		}
		return result;
	}
	
	public void readMetadata(String data) {
		try {
  		JSONObject json = new JSONObject(data);
  		Iterator<String> names = json.keys();
  		while (names.hasNext()) {
				String metaName = names.next();
				String metaValue = (String) json.get(metaName);
				metadata.add(new MetadataElement(metaName, metaValue));
			}
		} catch (JSONException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
private String metadataToString() {
    JSONObject json = new JSONObject();
    for (MetadataElement element : metadata) {
    	String name = element.getName();
    	String value = element.getValue();
    	if (!name.isEmpty() && !value.isEmpty()) {
    		json.put(element.getName(), element.getValue());	
    	}
    }
		return json.toString();
	}

public void writeMetadata(Object annotation) {
	XPropertySet properties = UnoRuntime.queryInterface(XPropertySet.class, annotation);
	XText startText = textRange.getText();
	try {
		properties.setPropertyValue("Author", METADATA_EXTENSION);
		properties.setPropertyValue("Content", metadataToString());
		XTextRange annotationRange = null;
		annotationRange = textRange;
		XTextField textField = UnoRuntime.queryInterface(XTextField.class, annotation);
		startText.insertTextContent( annotationRange, textField, true );
	} catch (IllegalArgumentException e) {
		e.printStackTrace();
	} catch (UnknownPropertyException e) {
		e.printStackTrace();
	} catch (PropertyVetoException e) {
		e.printStackTrace();
	} catch (WrappedTargetException e) {
		e.printStackTrace();
	}
}
	


}
